@@ -82,7 +82,7 @@ class Target(object):
             mask_20 &= array([(texp < 119) for texp in products['t_exptime']])
             mask_20 &= array(
                 [prov.lower() == 'spoc' for prov in products['provenance_name']])
-            mask_20 &= array([filename.endswith('_lc.fits') if isinstance(
+            mask_20 &= array([filename.endswith('lc.fits') if isinstance(
                 filename, str) else False for filename in products['dataURL']])
 
             obs_sectors_20 = sorted(products[mask_20]['sequence_number'])
@@ -134,16 +134,17 @@ def print_results(tic=12350, simbad_search=False, data_search=False):
         else:
             print()
             print('Target name: {}'.format(
-                result_table['MAIN_ID'][0].decode('utf-8')))
+                result_table['MAIN_ID'][0]))
         print("The target is in constellation {}".format(get_constellation(
             skobj)))
 
     if data_search:
         obs_sectors = target.get_obs()
         obs2, obsffi, obs20 = obs_sectors
-        print(f'FFI data at MAST for sectors:   {obsffi}')
-        print(f'2-min data at MAST for sectors: {obs2}')
-        print(f'20-s data at MAST for sectors:  {obs20}')
+
+        print(f'FFI data at MAST for sectors:   {sorted(list(set(obsffi)))}')
+        print(f'2-min data at MAST for sectors: {sorted(list(set(obs2)))}')
+        print(f'20-s data at MAST for sectors:  {sorted(list(set(obs20)))}')
 
     print()
 
